@@ -24,11 +24,6 @@
 
 (declare-function elisp-lint-file "ext:elsa.el")
 
-;;
-;;; Flags
-
-(advice-add #'eask-allow-error-p :override #'always)
-
 ;;
 ;;; Core
 
@@ -42,18 +37,19 @@
          success)
     (eask-msg "")
     (eask-msg "`%s` with elisp-lint (%s)" (ansi-green file) eask-lint-elisp-lint--version)
-    (eask-with-verbosity 'debug
-      (setq success (elisp-lint-file filename)))
-    ;; Report result!
-    (cond (success
-           (eask-msg "No issues found"))
-          ((eask-strict-p)
-           (eask-error "Linting failed")))))
+    (eask-ignore-errors
+      (eask-with-verbosity 'debug
+        (setq success (elisp-lint-file filename)))
+      ;; Report result!
+      (cond (success
+             (eask-msg "No issues found"))
+            ((eask-strict-p)
+             (eask-error "Linting failed"))))))
 
 (eask-start
   ;; Preparation
-  (eask-with-archives '("gnu" "melpa")
-    (eask-package-install 'elisp-lint))
+  (eask-archive-install-packages '("gnu" "melpa")
+                                 'elisp-lint)
   (setq eask-lint-elisp-lint--version (eask-package--version-string 'elisp-lint))
 
   ;; Start Linting
