@@ -19,11 +19,6 @@
 
 (require 'whitespace nil t)
 
-;;
-;;; Flags
-
-(advice-add #'eask-allow-error-p :override #'always)
-
 ;;
 ;;; Core
 
